/*
 * This file is a part of KEMET project (Library).
 * 
 * Copyright (C) 2008 MAUPIN Fabrice
 *
 * This library is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License 
 * as published by the Free Software Foundation; 
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this library; 
 * if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 */
package org.kemet.tests.determiner;

import org.apache.log4j.Logger;
import org.junit.Test;
import org.kemet.impl.grammar.model.Determiner;
import org.kemet.tests.TestRoot;

/**
 * 
 * 
 * @author fabricemaupin
 * 
 * <p>
 * <b>Tests for determiners management.</b>
 * </p>
 * 
 * @since 0.6
 * 
 */
public class TestDeterminer extends TestRoot {
	static Logger log = Logger.getLogger("org.kemet.tests");

	/**
	 * <p>
	 * <b>set the parameters before execute the tests.</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Override
	public void init() {
		// nothing
	}

	/**
	 * <p>
	 * <b>verify which is the substitute for determiners (Z5) and the number of
	 * substitutes (must be equal to 1).</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Test
	public void test1() {
		String id = "";
		int nb = 0;

		for (int j = 0; j < Determiner.getDeterminerInstances().size(); j++) {
			Determiner instance = (Determiner) Determiner
					.getDeterminerInstances().get(j);

			if (instance.isSubstitute()) {
				id = instance.getId();
				nb++;
			}
		}

		assertTrue(nb == 1);
		assertTrue(id.equals("Z5"));
	}

	/**
	 * <p>
	 * <b>verify if the determiner used for ideogram is the right determiner
	 * (Z1) and the number of these special determiners (must be equal to 1).</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Test
	public void test2() {
		String id = "";
		int nb = 0;
		
		for (int j = 0; j < Determiner.getDeterminerInstances().size(); j++) {
			Determiner instance = (Determiner) Determiner
					.getDeterminerInstances().get(j);

			if (instance.isUsedForIdeogram()) {
				id = instance.getId();
				nb++;
			}
		}

		assertTrue(nb == 1);
		assertTrue(id.equals("Z1"));
	}

	/**
	 * <p>
	 * <b>verify if the determiner used for define the feminine grammatical kind
	 * is the right determiner (X1) and the number of these special determiners
	 * (must be equal to 1).</b>
	 * </p>
	 * 
	 * @since 0.6
	 */
	@Test
	public void test3() {
		String id = "";
		int nb = 0;

		for (int j = 0; j < Determiner.getDeterminerInstances().size(); j++) {
			Determiner instance = (Determiner) Determiner
					.getDeterminerInstances().get(j);

			if (instance.isFeminineGrammaticalKind()) {
				id = instance.getId();
				nb++;
			}
		}

		assertTrue(nb == 1);
		assertTrue(id.equals("X1"));
	}
}
